Struct tinify::convert::Type

source ·
pub struct Type(/* private fields */);
Tinify currently supports converting between WebP, JPEG, and PNG.

When provided more than one image type in the convert request, the smallest version will be returned.

Implementations

source

impl Type

source

pub const PNG: &'static str = "image/png"

The "image/png" type.

source

pub const JPEG: &'static str = "image/jpeg"

The "image/jpeg" type.

source

pub const WEBP: &'static str = "image/webp"

The "image/webp" type.

source

pub const WILDCARD: &'static str = "*/*"

The wildcard "*/*" returns the smallest of Tinify’s supported image types, currently WebP, JPEG and PNG.