Enum tinify::TinifyError
source · pub enum TinifyError {
ClientError,
ServerError,
ReadError {
source: Error,
},
WriteError {
source: Error,
},
IOError(Error),
ReqwestError(Error),
}Expand description
The Tinify API uses HTTP status codes to indicate success or failure.
Status codes in the 4xx range indicate there was a problem with Client request.
Status codes in the 5xx indicate a temporary problem with the Tinify API Server.
Variants