Struct tinify::resize::Method

source ·
pub struct Method(/* private fields */);
The method describes the way the image will be resized.

Implementations

source

impl Method

source

pub const SCALE: &'static str = "scale"

Scales the image down proportionally.

source

pub const FIT: &'static str = "fit"

Scales the image down proportionally so that it fits within the given dimensions.

source

pub const COVER: &'static str = "cover"

Scales the image proportionally and crops it if necessary so that the result has exactly the given dimensions.

source

pub const THUMB: &'static str = "thumb"

A more advanced implementation of cover that also detects cut out images with plain backgrounds.