Struct tinify::resize::Resize

source ·
pub struct Resize { /* private fields */ }
Use the API to create resized versions of the uploaded images.

If the target dimensions are larger than the original dimensions, the image will not be scaled up. Scaling up is prevented in order to protect the quality of the images.

Implementations

source

impl Resize

source

pub fn new<M>(method: M, width: Option<u32>, height: Option<u32>) -> Self
where M: AsRef<str> + Into<String>,