pub struct Resize { /* private fields */ }Expand description
Use the API to create resized versions of the uploaded images.
If the target dimensions are larger than the original dimensions, the image will not be scaled up. Scaling up is prevented in order to protect the quality of the images.
Implementations