Struct tinify::ResizeMethod

source ·
pub struct ResizeMethod(_);
The method describes the way the image will be resized.

Implementations

Scales the image down proportionally.

Scales the image down proportionally so that it fits within the given dimensions.

Scales the image proportionally and crops it if necessary so that the result has exactly the given dimensions.

A more advanced implementation of cover that also detects cut out images with plain backgrounds.