Module transform

Module transform 

Structs

Transform
The transform object specifies the stylistic transformations that will be applied to your image. Include a background property to fill a transparent image’s background. The following options are available to specify a background color: