pub struct Transform {
pub background: String,
}Expand description
The transform object specifies the stylistic transformations that will be applied to your image. Include a background property to fill a transparent image’s background. The following options are available to specify a background color:
- A hex value. Custom background color using the color’s hex value:
#000000. whiteorblack. Only the colors white and black are supported as strings.
You must specify a background color if you wish to convert an image with a transparent background to an image type which does not support transparency (like JPEG).
Fields
background: StringTrait Implementations
sourceimpl<'de> Deserialize<'de> for Transform
impl<'de> Deserialize<'de> for Transform
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more