pub struct Type(/* private fields */);Expand description
Tinify currently supports converting between WebP, JPEG, and PNG.
When provided more than one image type in the convert request, the smallest version will be returned.
Implementations