pub struct Source { /* private fields */ }Implementations
sourceimpl Source
impl Source
sourcepub fn resize(self, resize: Resize) -> Result<Self, TinifyError>
pub fn resize(self, resize: Resize) -> Result<Self, TinifyError>
Resize the current compressed image.
Examples
use tinify::sync::Tinify;
use tinify::sync::Client;
use tinify::error::TinifyError;
use tinify::resize::Method;
use tinify::resize::Resize;
fn get_client() -> Result<Client, TinifyError> {
let key = "tinify api key";
let tinify = Tinify::new();
tinify
.set_key(key)
.get_client()
}
fn main() -> Result<(), TinifyError> {
let client = get_client()?;
let _ = client
.from_file("./unoptimized.jpg")?
.resize(Resize::new(
Method::FIT,
Some(400),
Some(200),
))?
.to_file("./resized.jpg")?;
Ok(())
}sourcepub fn convert<T>(
self,
convert_type: (Option<T>, Option<T>, Option<T>),
transform: Option<Color>
) -> Result<Self, TinifyError>
pub fn convert<T>( self, convert_type: (Option<T>, Option<T>, Option<T>), transform: Option<Color> ) -> Result<Self, TinifyError>
The following options are available as a type:
One image type, specified as a string "image/webp"
Multiple image types, specified as a tuple ("image/webp", "image/png").
The smallest of the provided image types will be returned.
The transform object specifies the stylistic transformations that will be applied to the image.
Include a background property to fill a transparent image’s background.
Specify a background color to convert an image with a transparent background to an image type which does not support transparency (like JPEG).
Examples
use tinify::Tinify;
use tinify::convert::Color;
use tinify::convert::Type;
use tinify::TinifyError;
fn main() -> Result<(), TinifyError> {
let _ = Tinify::new()
.set_key("api key")
.get_client()?
.from_url("https://tinypng.com/images/panda-happy.png")?
.convert((
Some(Type::JPEG),
None,
None,
),
Some(Color("#FF5733")),
)?
.to_file("./converted.webp");
Ok(())
}sourcepub fn to_file<P>(&self, path: P) -> Result<(), TinifyError>
pub fn to_file<P>(&self, path: P) -> Result<(), TinifyError>
Save the compressed image to a file.