Structs
- Transform
- The transform object specifies the stylistic transformations that will be applied to your image. Include a
background propertyto fill a transparent image’s background. The following options are available to specify a background color: